==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/pt-pt/Filter.js <==
({
	"clearFilterDialogTitle": "Limpar filtro",
	"filterDefDialogTitle": "Filtro",
	"incompleteRuleTip": "Esta regra não está completa.",
	"ruleTitleTemplate": "Regra ${0}",
	
	"conditionEqual": "igual",
	"conditionNotEqual": "não é igual",
	"conditionLess": "é menor do que",
	"conditionLessEqual": "menor ou igual",
	"conditionLarger": "é maior do que",
	"conditionLargerEqual": "maior ou igual",
	"conditionContains": "contém",
	"conditionIs": "é",
	"conditionStartsWith": "começa com",
	"conditionEndWith": "termina com",
	"conditionNotContain": "não contém",
	"conditionIsNot": "não é",
	"conditionNotStartWith": "não começa com",
	"conditionNotEndWith": "não termina com",
	"conditionBefore": "antes",
	"conditionAfter": "após",
	"conditionRange": "intervalo",
	
	"all": "tudo",
	"any": "qualquer",
	"relationAll": "todas as regras",
	"waiRelAll": "Corresponder a todas as seguintes regras:",
	"relationAny": "quaisquer regras",
	"waiRelAny": "Corresponder a qualquer uma das seguintes regras:",
	"relationMsgFront": "Corresponder",
	"relationMsgTail": "",
	"and": "and",
	"or": "or",
	
	"addRuleButton": "Adicionar regra",
	"waiAddRuleButton": "Adicionar uma nova regra",
	"removeRuleButton": "Remover regra",
	"waiRemoveRuleButtonTemplate": "Remover regra ${0}",
	
	"cancelButton": "Cancelar",
	"waiCancelButton": "Cancelar esta caixa de diálogo",
	"clearButton": "Limpar",
	"waiClearButton": "Limpar o filtro",
	"filterButton": "Filtro",
	"waiFilterButton": "Submeter o filtro",
	
	"columnSelectLabel": "Coluna",
	"waiColumnSelectTemplate": "Coluna para a regra ${0}",
	"conditionSelectLabel": "Condição",
	"waiConditionSelectTemplate": "Condição para a regra ${0}",
	"valueBoxLabel": "Valor",
	"waiValueBoxTemplate": "Introduzir valor para filtrar para a regra ${0}",
	
	"rangeTo": "a",
	"rangeTemplate": "de ${0} a ${1}",
	
	"statusTipHeaderColumn": "Coluna",
	"statusTipHeaderCondition": "Regras",
	"statusTipTitle": "Barra do filtro",
	"statusTipMsg": "Faça clique na barra de filtro para filtrar os valores em ${0}.",
	"anycolumn": "qualquer coluna",
	"statusTipTitleNoFilter": "Barra do filtro",
	"statusTipTitleHasFilter": "Filtro",
	"statusTipRelPre": "Correspondência",
	"statusTipRelPost": "regras.",
	
	"defaultItemsName": "itens",
	"filterBarMsgHasFilterTemplate": "${0} de ${1} ${2} apresentado(s).",
	"filterBarMsgNoFilterTemplate": "Nenhum filtro aplicado",
	
	"filterBarDefButton": "Definir filtro",
	"waiFilterBarDefButton": "Filtrar a tabela",
	"a11yFilterBarDefButton": "Filtrar...",
	"filterBarClearButton": "Limpar filtro",
	"waiFilterBarClearButton": "Limpar o filtro",
	"closeFilterBarBtn": "Fechar barra de filtro",
	
	"clearFilterMsg": "Este procedimento irá remover o filtro e apresentar todos os registos disponíveis.",
	"anyColumnOption": "Qualquer coluna",
	
	"trueLabelEditable": "Verificado",
	"trueLabel": "True",
	"falseLabel": "False"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/pt-pt/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "Limpar filtro",
	"filterDefDialogTitle": "Filtro",
	"ruleTitleTemplate": "Regra ${0}",
	
	"conditionEqual": "igual",
	"conditionNotEqual": "não é igual",
	"conditionLess": "é menor do que",
	"conditionLessEqual": "menor ou igual",
	"conditionLarger": "é maior do que",
	"conditionLargerEqual": "maior ou igual",
	"conditionContains": "contém",
	"conditionIs": "é",
	"conditionStartsWith": "começa com",
	"conditionEndWith": "termina com",
	"conditionNotContain": "não contém",
	"conditionIsNot": "não é",
	"conditionNotStartWith": "não começa com",
	"conditionNotEndWith": "não termina com",
	"conditionBefore": "antes",
	"conditionAfter": "após",
	"conditionRange": "intervalo",
	"conditionIsEmpty": "está vazio",
	
	"all": "tudo",
	"any": "qualquer",
	"relationAll": "todas as regras",
	"waiRelAll": "Corresponder a todas as seguintes regras:",
	"relationAny": "quaisquer regras",
	"waiRelAny": "Corresponder a qualquer uma das seguintes regras:",
	"relationMsgFront": "Corresponder",
	"relationMsgTail": "",
	"and": "and",
	"or": "or",
	
	"addRuleButton": "Adicionar regra",
	"waiAddRuleButton": "Adicionar uma nova regra",
	"removeRuleButton": "Remover regra",
	"waiRemoveRuleButtonTemplate": "Remover regra ${0}",
	
	"cancelButton": "Cancelar",
	"waiCancelButton": "Cancelar esta caixa de diálogo",
	"clearButton": "Limpar",
	"waiClearButton": "Limpar o filtro",
	"filterButton": "Filtro",
	"waiFilterButton": "Submeter o filtro",
	
	"columnSelectLabel": "Coluna",
	"waiColumnSelectTemplate": "Coluna para a regra ${0}",
	"conditionSelectLabel": "Condição",
	"waiConditionSelectTemplate": "Condição para a regra ${0}",
	"valueBoxLabel": "Valor",
	"waiValueBoxTemplate": "Introduzir valor para filtrar para a regra ${0}",
	
	"rangeTo": "a",
	"rangeTemplate": "de ${0} a ${1}",
	
	"statusTipHeaderColumn": "Coluna",
	"statusTipHeaderCondition": "Regras",
	"statusTipTitle": "Barra do filtro",
	"statusTipMsg": "Faça clique na barra de filtro para filtrar os valores em ${0}.",
	"anycolumn": "qualquer coluna",
	"statusTipTitleNoFilter": "Barra do filtro",
	"statusTipTitleHasFilter": "Filtro",
	
	"defaultItemsName": "itens",
	"filterBarMsgHasFilterTemplate": "${0} de ${1} ${2} apresentado(s).",
	"filterBarMsgNoFilterTemplate": "Nenhum filtro aplicado",
	
	"filterBarDefButton": "Definir filtro",
	"waiFilterBarDefButton": "Filtrar a tabela",
	"a11yFilterBarDefButton": "Filtrar...",
	"filterBarClearButton": "Limpar filtro",
	"waiFilterBarClearButton": "Limpar o filtro",
	"closeFilterBarBtn": "Fechar barra de filtro",
	
	"clearFilterMsg": "Este procedimento irá remover o filtro e apresentar todos os registos disponíveis.",
	"anyColumnOption": "Qualquer coluna",
	
	"trueLabel": "True",
	"falseLabel": "False"
})
//end v1.x content
);
